==> cdk-cx-api-1.65.0-sources.jar: software/amazon/awscdk/cxapi/RuntimeInfo.java <==
package software.amazon.awscdk.cxapi;

/**
 * Backwards compatibility for when `RuntimeInfo` was defined here.
 * <p>
 * This is necessary because its used as an input in the stable
 * <p>
 * @see core.ConstructNode.synth
 * @deprecated moved to package 'cloud-assembly-schema'
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.12.0 (build 5ddc9f2)", date = "2020-10-01T01:49:28.968Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.cxapi.$Module.class, fqn = "@aws-cdk/cx-api.RuntimeInfo")
@software.amazon.jsii.Jsii.Proxy(RuntimeInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface RuntimeInfo extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.cloudassembly.schema.RuntimeInfo {

    /**
     * @return a {@link Builder} of {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<RuntimeInfo> {
        private java.util.Map<java.lang.String, java.lang.String> libraries;

        /**
         * Sets the value of {@link RuntimeInfo#getLibraries}
         * @param libraries The list of libraries loaded in the application, associated with their versions. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder libraries(java.util.Map<java.lang.String, java.lang.String> libraries) {
            this.libraries = libraries;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RuntimeInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public RuntimeInfo build() {
            return new Jsii$Proxy(libraries);
        }
    }

    /**
     * An implementation for {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RuntimeInfo {
        private final java.util.Map<java.lang.String, java.lang.String> libraries;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.libraries = this.jsiiGet("libraries", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.util.Map<java.lang.String, java.lang.String> libraries) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.libraries = java.util.Objects.requireNonNull(libraries, "libraries is required");
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.String> getLibraries() {
            return this.libraries;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("libraries", om.valueToTree(this.getLibraries()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/cx-api.RuntimeInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RuntimeInfo.Jsii$Proxy that = (RuntimeInfo.Jsii$Proxy) o;

            return this.libraries.equals(that.libraries);
        }

        @Override
        public int hashCode() {
            int result = this.libraries.hashCode();
            return result;
        }
    }
}

==> cdk-cx-api-1.66.0-sources.jar: software/amazon/awscdk/cxapi/RuntimeInfo.java <==
package software.amazon.awscdk.cxapi;

/**
 * (deprecated) Backwards compatibility for when `RuntimeInfo` was defined here.
 * <p>
 * This is necessary because its used as an input in the stable
 * <p>
 * @see core.ConstructNode.synth
 * @deprecated moved to package 'cloud-assembly-schema'
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.13.0 (build 385c325)", date = "2020-10-02T20:10:50.253Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.cxapi.$Module.class, fqn = "@aws-cdk/cx-api.RuntimeInfo")
@software.amazon.jsii.Jsii.Proxy(RuntimeInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface RuntimeInfo extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.cloudassembly.schema.RuntimeInfo {

    /**
     * @return a {@link Builder} of {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<RuntimeInfo> {
        private java.util.Map<java.lang.String, java.lang.String> libraries;

        /**
         * Sets the value of {@link RuntimeInfo#getLibraries}
         * @param libraries The list of libraries loaded in the application, associated with their versions. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder libraries(java.util.Map<java.lang.String, java.lang.String> libraries) {
            this.libraries = libraries;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RuntimeInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public RuntimeInfo build() {
            return new Jsii$Proxy(libraries);
        }
    }

    /**
     * An implementation for {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RuntimeInfo {
        private final java.util.Map<java.lang.String, java.lang.String> libraries;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.libraries = this.jsiiGet("libraries", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.util.Map<java.lang.String, java.lang.String> libraries) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.libraries = java.util.Objects.requireNonNull(libraries, "libraries is required");
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.String> getLibraries() {
            return this.libraries;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("libraries", om.valueToTree(this.getLibraries()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/cx-api.RuntimeInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RuntimeInfo.Jsii$Proxy that = (RuntimeInfo.Jsii$Proxy) o;

            return this.libraries.equals(that.libraries);
        }

        @Override
        public int hashCode() {
            int result = this.libraries.hashCode();
            return result;
        }
    }
}
